@@ -1,8 +1,8 @@
 #' @aliases shapviz-package
 "_PACKAGE"
 
-#' @import ggplot2
-NULL
+# Suppress R CMD check note
+#' @importFrom xgboost xgb.train
 
 globalVariables(c("from", "i", "id", "label", "to", "x", "shap",
                   "feature", "value", "color", "Var2", "Var3", "S"))
